@@ -11,7 +11,7 @@ from sql_cli.constants import DEFAULT_AIRFLOW_HOME, DEFAULT_DAGS_FOLDER
 from sql_cli.dag_generator import generate_dag
 from sql_cli.project import Project
 from sql_cli.run_dag import run_dag
-from sql_cli.utils.airflow_utils import (
+from sql_cli.utils.airflow import (
     get_dag,
     retrieve_airflow_database_conn_from_config,
     set_airflow_database_conn,
@@ -46,23 +46,17 @@ def generate(
         show_default=False,
         help="name of the workflow directory within workflows directory.",
     ),
-    environment: str = typer.Argument(
+    env: str = typer.Option(
         default="default",
         help="environment to run in",
     ),
-    project_dir: Path = typer.Argument(
+    project_dir: Path = typer.Option(
         None, dir_okay=True, metavar="PATH", help="(Optional) Default: current directory.", show_default=False
     ),
 ) -> None:
     project_dir_absolute = project_dir.resolve() if project_dir else Path.cwd()
     project = Project(project_dir_absolute)
-    project.load_config(environment)
-
-    # Since we are using the Airflow ORM to interact with connections, we need to tell Airflow to use our airflow.db
-    # The usual route is to set $AIRFLOW_HOME before Airflow is imported. However, in the context of the SQL CLI, we
-    # decide this during runtime, depending on the project path and SQL CLI configuration.
-    airflow_meta_conn = retrieve_airflow_database_conn_from_config(project.directory / project.airflow_home)
-    set_airflow_database_conn(airflow_meta_conn)
+    project.load_config(env)
 
     dag_file = generate_dag(
         directory=project.directory / project.workflows_directory / workflow_name,
@@ -80,7 +74,7 @@ def validate(
     project_dir: Path = typer.Argument(
         None, dir_okay=True, metavar="PATH", help="(Optional) Default: current directory.", show_default=False
     ),
-    environment: str = typer.Option(
+    env: str = typer.Option(
         default="default",
         help="(Optional) Environment used to declare the connections to be validated",
     ),
@@ -92,7 +86,7 @@ def validate(
     project_dir_absolute = project_dir.resolve() if project_dir else Path.cwd()
     project = Project(project_dir_absolute)
 
-    validate_connections(project=project, environment=environment, connection_id=connection)
+    validate_connections(project=project, environment=env, connection_id=connection)
 
 
 @app.command(
